@@ -42,7 +42,7 @@ sub output {
     $opts{useAjax}=($opts{useAjax}) ? 1 : 0;
   }
 
-  $opts{httpHeader} = $$o{q}->header(-type=>'text/html',-expires=>'now')
+  $opts{httpHeader} = $$o{httpHeader}->(-type=>'text/html',-expires=>'now')
     unless exists $opts{httpHeader};
   $opts{htmlFooter} = "</body>\n</html>\n"
     unless exists $opts{htmlFooter};
@@ -117,14 +117,14 @@ sub output {
   }
 
   $buf = $opts{httpHeader}.$opts{htmlHeader};
-  $buf .= "<script src=$$o{schema}{resourceURI}/jquery.js?$ver></script><noscript>Javascript is required when viewing this page.</noscript>" unless $opts{jquery_already_sent};
+  $buf .= "<script src=$$o{schema}{resourceURI}/jquery.js?$ver></script>" unless $opts{jquery_already_sent};
   $buf .= "
-<script src=$$o{schema}{resourceURI}/InteractiveQuery2.js?a$ver></script><noscript>Javascript is required when viewing this page.</noscript>
+<script src=$$o{schema}{resourceURI}/InteractiveQuery2.js?$ver></script>
 <script>
 (function(){
 $script
 })();
-</script><noscript>Javascript is required when viewing this page.</noscript>";
+</script>";
   $buf .= "
 <div class=OQdoc>
 <div class=OQdocTop>$opts{OQdocTop}</div>";
@@ -152,16 +152,17 @@ $script
 <form class='OQform mode-$$o{mode}' name=OQform action='".escapeHTML($$o{schema}{URI_standalone}||$$o{schema}{URI})."' method=get>
 <input type=hidden name=show value='".escapeHTML(join(',',@{$$o{show}}))."'>
 <input type=hidden name=filter value='".escapeHTML($$o{filter})."'>
-<input type=hidden name=mode value='".escapeHTML($$o{mode})."'>
 <input type=hidden name=hiddenFilter value='".escapeHTML($$o{hiddenFilter})."'>
 <input type=hidden name=queryDescr value='".escapeHTML($$o{queryDescr})."'>
-<input type=hidden name=sort value='".escapeHTML($$o{'sort'})."'>
-<input type=hidden name=module value='".escapeHTML($$o{module})."'>
-<input type=hidden name=OQss value='".escapeHTML($$o{q}->param('OQss'))."'>
-<input type=hidden name=on_select value='".escapeHTML($$o{q}->param('on_select'))."'>\n";
-  if (ref($$o{schema}{state_params}) eq 'ARRAY') {
-    $buf .= "<input type=hidden name='".escapeHTML($_)."' value='"
-         .escapeHTML($$o{q}->param($_))."'>\n" for @{$$o{schema}{state_params}};
+<input type=hidden name=sort value='".escapeHTML($$o{'sort'})."'>\n";
+  $buf .= "<input type=hidden name=mode value='".escapeHTML($$o{mode})."'>\n" if $$o{mode};
+  $buf .= "<input type=hidden name=module value='".escapeHTML($$o{module})."'>\n" if $$o{module};
+
+  my @p = qw( OQss on_select on_update );
+  push @p, @{ $$o{schema}{state_params} } if ref($$o{schema}{state_params}) eq 'ARRAY'; 
+  foreach my $p (@p) {
+    my $v = $$o{q}->param($p);
+    $buf .= "<input type=hidden name='".escapeHTML($p)."' value='".escapeHTML($v)."'>\n" if $v ne '';
   }
 
   $buf .=
@@ -245,6 +246,9 @@ $newBut
   }
 
 
+$$o{output_handler}->($buf);
+$buf = '';
+
   $buf .= "<table class=OQdata>";
 
   if ($$o{mode} eq 'recview') {
@@ -326,13 +330,18 @@ $newBut
       foreach my $col (@{ $o->get_usersel_cols }) {
         my $val = $o->get_html_val($col);
         my $type = $$typeMap{$col} || 'char';
-        $buf .= "<td".(($type ne 'char')?" class=$type":"").">$val</td>";
+        $buf .= "<td";
+        $buf .= " class=$type" unless $type eq 'char';
+        $buf .= " nowrap" if $$o{schema}{select}{$col}[3]{nowrap};
+        $buf .= " align='".escapeHTML($$o{schema}{select}{$col}[3]{align})."'"
+          if $$o{schema}{select}{$col}[3]{align};
+        $buf .= ">$val</td>";
       }
       $buf .= "<td class=OQdataRCol>$rightBut</td>";
     }
 
     $buf .= "</tr>\n";
-    if (++$recs_in_buffer == 10000) {
+    if (++$recs_in_buffer == 1000) {
       $$o{output_handler}->($buf);
       $buf = '';
       $recs_in_buffer = 0;
